API
####

This is a reference for the public objects, functions and methods in glue genes.

.. toctree::
  :maxdepth: 2

  Input/output <reference/io>
  Single Cell Data <reference/singlecelldata.rst>
  Imaging Data <reference/imagingdata.rst>
  Custom Viewers <reference/viewers.rst>
  Analysis Plugins <reference/analysis.rst>
